@@ -4,8 +4,8 @@
 //! not meant to be used directly, but can be used in the implementation
 //! of new measures.
 
-use op::Operation;
-use SeqPair;
+use crate::op::Operation;
+use crate::SeqPair;
 
 /// Delete operation with associated cost.
 #[derive(Clone, Debug, Eq, Hash, PartialEq)]
@@ -28,14 +28,15 @@ impl<T> Operation<T> for Delete {
     fn cost(
         &self,
         seq_pair: &SeqPair<T>,
-        cost_matrix: &Vec<Vec<usize>>,
+        cost_matrix: &[Vec<usize>],
         source_idx: usize,
         target_idx: usize,
     ) -> Option<usize>
     where
         T: Eq,
     {
-        let (from_source_idx, from_target_idx) = self.backtrack(seq_pair, source_idx, target_idx)?;
+        let (from_source_idx, from_target_idx) =
+            self.backtrack(seq_pair, source_idx, target_idx)?;
         let orig_cost = cost_matrix[from_source_idx][from_target_idx];
         Some(orig_cost + self.0)
     }
@@ -62,14 +63,15 @@ impl<T> Operation<T> for Insert {
     fn cost(
         &self,
         seq_pair: &SeqPair<T>,
-        cost_matrix: &Vec<Vec<usize>>,
+        cost_matrix: &[Vec<usize>],
         source_idx: usize,
         target_idx: usize,
     ) -> Option<usize>
     where
         T: Eq,
     {
-        let (from_source_idx, from_target_idx) = self.backtrack(seq_pair, source_idx, target_idx)?;
+        let (from_source_idx, from_target_idx) =
+            self.backtrack(seq_pair, source_idx, target_idx)?;
         let orig_cost = cost_matrix[from_source_idx][from_target_idx];
         Some(orig_cost + self.0)
     }
@@ -96,14 +98,15 @@ impl<T> Operation<T> for Match {
     fn cost(
         &self,
         seq_pair: &SeqPair<T>,
-        cost_matrix: &Vec<Vec<usize>>,
+        cost_matrix: &[Vec<usize>],
         source_idx: usize,
         target_idx: usize,
     ) -> Option<usize>
     where
         T: Eq,
     {
-        let (from_source_idx, from_target_idx) = self.backtrack(seq_pair, source_idx, target_idx)?;
+        let (from_source_idx, from_target_idx) =
+            self.backtrack(seq_pair, source_idx, target_idx)?;
 
         if seq_pair.source[from_source_idx] == seq_pair.target[from_target_idx] {
             Some(cost_matrix[from_source_idx][from_target_idx])
@@ -134,14 +137,15 @@ impl<T> Operation<T> for Substitute {
     fn cost(
         &self,
         seq_pair: &SeqPair<T>,
-        cost_matrix: &Vec<Vec<usize>>,
+        cost_matrix: &[Vec<usize>],
         source_idx: usize,
         target_idx: usize,
     ) -> Option<usize>
     where
         T: Eq,
     {
-        let (from_source_idx, from_target_idx) = self.backtrack(seq_pair, source_idx, target_idx)?;
+        let (from_source_idx, from_target_idx) =
+            self.backtrack(seq_pair, source_idx, target_idx)?;
         let orig_cost = cost_matrix[from_source_idx][from_target_idx];
         Some(orig_cost + self.0)
     }
@@ -168,14 +172,15 @@ impl<T> Operation<T> for Transpose {
     fn cost(
         &self,
         seq_pair: &SeqPair<T>,
-        cost_matrix: &Vec<Vec<usize>>,
+        cost_matrix: &[Vec<usize>],
         source_idx: usize,
         target_idx: usize,
     ) -> Option<usize>
     where
         T: Eq,
     {
-        let (from_source_idx, from_target_idx) = self.backtrack(seq_pair, source_idx, target_idx)?;
+        let (from_source_idx, from_target_idx) =
+            self.backtrack(seq_pair, source_idx, target_idx)?;
 
         if seq_pair.source[from_source_idx] == seq_pair.target[from_target_idx + 1]
             && seq_pair.source[from_source_idx + 1] == seq_pair.target[from_target_idx]
